@@ -132,4 +132,13 @@ def test_score2(h, i):
     score = int(score*(i/100)+20)
     if score > 100:
         score = 100
-    return score
\ No newline at end of file
+    return score
+
+
+def get_eq_info():
+    dc_url = "https://api.p2pquake.net/v2/jma/quake?limit=1"
+    resp = requests.get(dc_url)
+    ql = loads(r.read())
+    q = ql[0]
+    return q.get("earthquake", {})
+
